#!/usr/bin/env python

"""
Scheduling functions manifest.

Copyright (C) 2017 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.imports import get_extensions
from os.path import split

reserved = ["__init__", "common", "manifest"]

# Obtain details of this module's package.

dirname = split(__file__)[0]
package = __name__.rsplit(".", 1)[0]

# Define an attribute mapping names to modules.

modules = {}
get_extensions(dirname, package, modules, reserved)

# Define attributes mapping names to functions.

confirmation_functions = {}
locking_functions = {}
retraction_functions = {}
scheduling_functions = {}
unlocking_functions = {}

for module in modules.values():
    confirmation_functions.update(module.confirmation_functions)
    locking_functions.update(module.locking_functions)
    retraction_functions.update(module.retraction_functions)
    scheduling_functions.update(module.scheduling_functions)
    unlocking_functions.update(module.unlocking_functions)

# vim: tabstop=4 expandtab shiftwidth=4
